@@ -1,17 +1,7 @@
 /*
- *
- * Copyright (C) 2003-2009 Sebastian Trueg <trueg@k3b.org>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2009 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
-
+    SPDX-FileCopyrightText: 1998-2009 Sebastian Trueg <trueg@k3b.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "k3bgrowisofswriter.h"
 
 #include "k3bcore.h"
@@ -335,7 +325,7 @@ void K3b::GrowisofsWriter::start()
 
         qDebug() << "***** " << d->growisofsBin->name() << " parameters:\n";
         QString s = d->process.joinedArgs();
-        qDebug() << s << flush;
+        qDebug() << s << Qt::flush;
         emit debuggingOutput( d->growisofsBin->name() + " command:", s);
 
 
@@ -473,7 +463,7 @@ void K3b::GrowisofsWriter::slotReceivedStderr( const QString& line )
                 }
                 else
                     qDebug() << "(K3b::GrowisofsWriter) speed parsing failed: '"
-                             << line.mid( pos, line.indexOf( 'x', pos ) - pos ) << "'" << endl;
+                             << line.mid( pos, line.indexOf( 'x', pos ) - pos ) << "'" << Qt::endl;
             }
             else {
                 d->speedEst->dataWritten( done/1024 );
@@ -481,7 +471,7 @@ void K3b::GrowisofsWriter::slotReceivedStderr( const QString& line )
         }
         else
             qDebug() << "(K3b::GrowisofsWriter) progress parsing failed: '"
-                     << line.mid( pos+1, line.indexOf( '(', pos ) - pos - 1 ).trimmed() << "'" << endl;
+                     << line.mid( pos+1, line.indexOf( '(', pos ) - pos - 1 ).trimmed() << "'" << Qt::endl;
     }
 
     //  else
