@@ -17,6 +17,7 @@
 #include "k3bplugin_i18n.h"
 
 #include <KConfig>
+#include <KConfigGroup>
 #include <KSharedConfig>
 
 #include <QDebug>
@@ -217,7 +218,7 @@ bool K3bSoxEncoder::initEncoderInternal( const QString& extension, const K3b::Ms
 
         qDebug() << "***** sox parameters:";
         QString s = d->process->joinedArgs();
-        qDebug() << s << flush;
+        qDebug() << s << Qt::flush;
 
         return d->process->start( KProcess::MergedChannels );
     }
