@@ -9,9 +9,15 @@
 #ifndef K3BHELPER_H
 #define K3BHELPER_H
 
-#include <KAuthActionReply>
 #include <QObject>
 
+#include <kauth_version.h>
+#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
+#include <KAuth/ActionReply>
+#else
+#include <KAuthActionReply>
+#endif
+
 using namespace KAuth;
 
 namespace K3b {
