@@ -1,17 +1,9 @@
 /*
- *
- * Copyright (C) 2003-2008 Sebastian Trueg <trueg@k3b.org>
- * Copyright (C) 2011 Michal Malek <michalm@jabster.pl>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2008 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
+    SPDX-FileCopyrightText: 2003-2008 Sebastian Trueg <trueg@k3b.org>
+    SPDX-FileCopyrightText: 2011 Michal Malek <michalm@jabster.pl>
+    SPDX-FileCopyrightText: 1998-2008 Sebastian Trueg <trueg@k3b.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <config-k3b.h>
 #include "k3bdirview.h"
@@ -198,7 +190,7 @@ void K3b::DirView::showMediumInfo( const K3b::Medium& medium )
             d->videoView->reload( medium );
         }
         else {
-            KMessageBox::sorry( this, i18n("K3b uses vcdxrip from the vcdimager package to rip Video CDs. "
+            KMessageBox::error( this, i18n("K3b uses vcdxrip from the vcdimager package to rip Video CDs. "
                                            "Please make sure it is installed.") );
             k3bappcore->appDeviceManager()->mountDisk( medium.device() );
         }
