@@ -1,17 +1,7 @@
 /*
- *
- * $Id$
- * Copyright (C) 2003-2007 Sebastian Trueg <trueg@k3b.org>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
+    SPDX-FileCopyrightText: 1998-2007 Sebastian Trueg <trueg@k3b.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "k3bprojectmanager.h"
 
@@ -40,7 +30,7 @@
 #include <KSharedConfig>
 #include <KLocalizedString>
 #include <KIO/StoredTransferJob>
-#include <KIO/CopyJob>
+#include <KIO/FileCopyJob>
 #include <KMessageBox>
 
 #include <QDebug>
@@ -622,7 +612,7 @@ bool K3b::ProjectManager::saveProject( K3b::Doc* doc, const QUrl& url )
             }
         }
     }
-    KIO::CopyJob *copyJob = KIO::move(QUrl::fromLocalFile(tmpfile.fileName()), url);
+    KIO::FileCopyJob *copyJob = KIO::file_move(QUrl::fromLocalFile(tmpfile.fileName()), url, -1, KIO::Overwrite);
     copyJob->exec();
 
     return success;
