@@ -362,7 +362,7 @@ void K3b::MediaCopyDialog::slotStartClicked()
     }
     else {
         // do not translate this as it is not intended to be included in the stable version!
-        KMessageBox::sorry( this, "Ups", "No copy support for this source media type yet." );
+        KMessageBox::error( this, "Ups", "No copy support for this source media type yet." );
         return;
     }
 
