@@ -11,7 +11,7 @@
 #include "k3bwavefilewriter.h"
 
 #include <KLocalizedString>
-#include <KCddb/Cdinfo>
+#include <KCDDB/CDInfo>
 
 #include <QDebug>
 #include <QDir>
@@ -218,7 +218,9 @@ bool MassAudioEncodingJob::run()
     d->overallBytesToRead = 0;
     d->lengths.clear();
 
-    Q_FOREACH( const QString& filename, d->tracks.keys().toSet() ) {
+    const QStringList tracksKeys = d->tracks.keys();
+    const QSet<QString> fileNames = QSet<QString>(tracksKeys.begin(), tracksKeys.end());
+    Q_FOREACH( const QString& filename, fileNames ) {
         d->lengths.insert( filename, 0 );
         Q_FOREACH( int trackNumber, d->tracks.values( filename ) ) {
             const Msf length = trackLength( trackNumber );
@@ -406,7 +408,7 @@ bool MassAudioEncodingJob::writePlaylist()
         QTextStream t( &f );
 
         // format descriptor
-        t << "#EXTM3U" << endl;
+        t << "#EXTM3U" << Qt::endl;
 
         // Get list of the ripped filenames sorted by track number
         QStringList filenames = d->tracks.keys();
@@ -433,17 +435,17 @@ bool MassAudioEncodingJob::writePlaylist()
             }
 
             if( !artist.toString().isEmpty() && !title.toString().isEmpty() ) {
-                t << artist.toString() << " - " << title.toString() << endl;
+                t << artist.toString() << " - " << title.toString() << Qt::endl;
             }
             else {
-                t << QFileInfo( trackFile ).baseName() << endl;
+                t << QFileInfo( trackFile ).baseName() << Qt::endl;
             }
 
             // filename
             if( d->relativePathInPlaylist )
-                t << playlistDir.relativeFilePath( trackFile ) << endl;
+                t << playlistDir.relativeFilePath( trackFile ) << Qt::endl;
             else
-                t << trackFile << endl;
+                t << trackFile << Qt::endl;
         }
 
         return ( t.status() == QTextStream::Ok );
@@ -459,7 +461,9 @@ bool MassAudioEncodingJob::writePlaylist()
 bool MassAudioEncodingJob::writeCueFile()
 {
     bool success = true;
-    Q_FOREACH( const QString& filename, d->tracks.keys().toSet() ) {
+    const QStringList tracksKeys = d->tracks.keys();
+    const QSet<QString> fileNames = QSet<QString>(tracksKeys.begin(), tracksKeys.end());
+    Q_FOREACH( const QString& filename, fileNames ) {
         CueFileWriter cueWriter;
 
         // create a new toc and cd-text
