@@ -1,16 +1,9 @@
 /*
- *
- * Copyright (C) 2006-2009 Sebastian Trueg <trueg@k3b.org>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2009 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
+    SPDX-FileCopyrightText: 2006-2009 Sebastian Trueg <trueg@k3b.org>
+    SPDX-FileCopyrightText: 1998-2009 Sebastian Trueg <trueg@k3b.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "k3bvideodvdrippingdialog.h"
 #include "k3bapplication.h"
@@ -496,7 +489,7 @@ void K3b::VideoDVDRippingDialog::slotStartClicked()
         for( TitleRipInfos::iterator it = d->titleRipInfos.begin(); it != d->titleRipInfos.end(); ++it ) {
             if( d->dvd[it.value().title-1].numAudioStreams() > 0 &&
                 d->dvd[it.value().title-1].audioStream(it.value().audioStream).format() != K3b::VideoDVD::AUDIO_FORMAT_AC3 ) {
-                KMessageBox::sorry( this, i18n("<p>When using the <em>AC3 pass-through</em> audio codec all selected audio "
+                KMessageBox::error( this, i18n("<p>When using the <em>AC3 pass-through</em> audio codec all selected audio "
                                                "streams need to be in AC3 format. Please select another audio codec or "
                                                "choose AC3 audio streams for all ripped titles."),
                                     i18n("AC3 Pass-through") );
